==> vtk-6.3.0-5-armv6h.pkg.tar.xz: vtk/vtkGenericEdgeTable.java <==
// java wrapper for vtkGenericEdgeTable object
//

package vtk;
import vtk.*;

public class vtkGenericEdgeTable extends vtkObject
{

  private native String GetClassName_0();
  public String GetClassName()
    { return GetClassName_0(); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void InsertEdge_2(int id0,int id1,int id2,int id3);
  public void InsertEdge(int id0,int id1,int id2,int id3)
    { InsertEdge_2(id0,id1,id2,id3); }

  private native int RemoveEdge_3(int id0,int id1);
  public int RemoveEdge(int id0,int id1)
    { return RemoveEdge_3(id0,id1); }

  private native int IncrementEdgeReferenceCount_4(int id0,int id1,int id2);
  public int IncrementEdgeReferenceCount(int id0,int id1,int id2)
    { return IncrementEdgeReferenceCount_4(id0,id1,id2); }

  private native int CheckEdgeReferenceCount_5(int id0,int id1);
  public int CheckEdgeReferenceCount(int id0,int id1)
    { return CheckEdgeReferenceCount_5(id0,id1); }

  private native void Initialize_6(int id0);
  public void Initialize(int id0)
    { Initialize_6(id0); }

  private native int GetNumberOfComponents_7();
  public int GetNumberOfComponents()
    { return GetNumberOfComponents_7(); }

  private native void SetNumberOfComponents_8(int id0);
  public void SetNumberOfComponents(int id0)
    { SetNumberOfComponents_8(id0); }

  private native int CheckPoint_9(int id0);
  public int CheckPoint(int id0)
    { return CheckPoint_9(id0); }

  private native void InsertPoint_10(int id0,double id1[]);
  public void InsertPoint(int id0,double id1[])
    { InsertPoint_10(id0,id1); }

  private native void RemovePoint_11(int id0);
  public void RemovePoint(int id0)
    { RemovePoint_11(id0); }

  private native void IncrementPointReferenceCount_12(int id0);
  public void IncrementPointReferenceCount(int id0)
    { IncrementPointReferenceCount_12(id0); }

  private native void DumpTable_13();
  public void DumpTable()
    { DumpTable_13(); }

  private native void LoadFactor_14();
  public void LoadFactor()
    { LoadFactor_14(); }

  public vtkGenericEdgeTable() { super(); }

  public vtkGenericEdgeTable(long id) { super(id); }
  public native long   VTKInit();

}

==> vtk-8.2.0-17-armv6h.pkg.tar.xz: vtk/vtkGenericEdgeTable.java <==
// java wrapper for vtkGenericEdgeTable object
//

package vtk;
import vtk.*;

public class vtkGenericEdgeTable extends vtkObject
{

  private native int IsTypeOf_0(String id0);
  public int IsTypeOf(String id0)
    { return IsTypeOf_0(id0); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void InsertEdge_2(int id0,int id1,int id2,int id3);
  public void InsertEdge(int id0,int id1,int id2,int id3)
    { InsertEdge_2(id0,id1,id2,id3); }

  private native int RemoveEdge_3(int id0,int id1);
  public int RemoveEdge(int id0,int id1)
    { return RemoveEdge_3(id0,id1); }

  private native int IncrementEdgeReferenceCount_4(int id0,int id1,int id2);
  public int IncrementEdgeReferenceCount(int id0,int id1,int id2)
    { return IncrementEdgeReferenceCount_4(id0,id1,id2); }

  private native int CheckEdgeReferenceCount_5(int id0,int id1);
  public int CheckEdgeReferenceCount(int id0,int id1)
    { return CheckEdgeReferenceCount_5(id0,id1); }

  private native void Initialize_6(int id0);
  public void Initialize(int id0)
    { Initialize_6(id0); }

  private native int GetNumberOfComponents_7();
  public int GetNumberOfComponents()
    { return GetNumberOfComponents_7(); }

  private native void SetNumberOfComponents_8(int id0);
  public void SetNumberOfComponents(int id0)
    { SetNumberOfComponents_8(id0); }

  private native int CheckPoint_9(int id0);
  public int CheckPoint(int id0)
    { return CheckPoint_9(id0); }

  private native void InsertPoint_10(int id0,double id1[]);
  public void InsertPoint(int id0,double id1[])
    { InsertPoint_10(id0,id1); }

  private native void RemovePoint_11(int id0);
  public void RemovePoint(int id0)
    { RemovePoint_11(id0); }

  private native void IncrementPointReferenceCount_12(int id0);
  public void IncrementPointReferenceCount(int id0)
    { IncrementPointReferenceCount_12(id0); }

  private native void DumpTable_13();
  public void DumpTable()
    { DumpTable_13(); }

  private native void LoadFactor_14();
  public void LoadFactor()
    { LoadFactor_14(); }

  public vtkGenericEdgeTable() { super(); }

  public vtkGenericEdgeTable(long id) { super(id); }
  public native long   VTKInit();

}
